==> kubernetes-model-flowcontrol-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/PolicyRulesWithSubjectsFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface PolicyRulesWithSubjectsFluent<A extends PolicyRulesWithSubjectsFluent<A>> extends Fluent<A>{
  public A addToNonResourceRules(Integer index,NonResourcePolicyRule item);
  public A setToNonResourceRules(Integer index,NonResourcePolicyRule item);
  public A addToNonResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.NonResourcePolicyRule... items);
  public A addAllToNonResourceRules(Collection<NonResourcePolicyRule> items);
  public A removeFromNonResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.NonResourcePolicyRule... items);
  public A removeAllFromNonResourceRules(Collection<NonResourcePolicyRule> items);
  public A removeMatchingFromNonResourceRules(Predicate<NonResourcePolicyRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildNonResourceRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NonResourcePolicyRule> getNonResourceRules();
  public List<NonResourcePolicyRule> buildNonResourceRules();
  public NonResourcePolicyRule buildNonResourceRule(Integer index);
  public NonResourcePolicyRule buildFirstNonResourceRule();
  public NonResourcePolicyRule buildLastNonResourceRule();
  public NonResourcePolicyRule buildMatchingNonResourceRule(Predicate<NonResourcePolicyRuleBuilder> predicate);
  public Boolean hasMatchingNonResourceRule(Predicate<NonResourcePolicyRuleBuilder> predicate);
  public A withNonResourceRules(List<NonResourcePolicyRule> nonResourceRules);
  public A withNonResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.NonResourcePolicyRule... nonResourceRules);
  public Boolean hasNonResourceRules();
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> addNewNonResourceRule();
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> addNewNonResourceRuleLike(NonResourcePolicyRule item);
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> setNewNonResourceRuleLike(Integer index,NonResourcePolicyRule item);
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> editNonResourceRule(Integer index);
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> editFirstNonResourceRule();
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> editLastNonResourceRule();
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> editMatchingNonResourceRule(Predicate<NonResourcePolicyRuleBuilder> predicate);
  public A addToResourceRules(Integer index,ResourcePolicyRule item);
  public A setToResourceRules(Integer index,ResourcePolicyRule item);
  public A addToResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.ResourcePolicyRule... items);
  public A addAllToResourceRules(Collection<ResourcePolicyRule> items);
  public A removeFromResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.ResourcePolicyRule... items);
  public A removeAllFromResourceRules(Collection<ResourcePolicyRule> items);
  public A removeMatchingFromResourceRules(Predicate<ResourcePolicyRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResourceRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourcePolicyRule> getResourceRules();
  public List<ResourcePolicyRule> buildResourceRules();
  public ResourcePolicyRule buildResourceRule(Integer index);
  public ResourcePolicyRule buildFirstResourceRule();
  public ResourcePolicyRule buildLastResourceRule();
  public ResourcePolicyRule buildMatchingResourceRule(Predicate<ResourcePolicyRuleBuilder> predicate);
  public Boolean hasMatchingResourceRule(Predicate<ResourcePolicyRuleBuilder> predicate);
  public A withResourceRules(List<ResourcePolicyRule> resourceRules);
  public A withResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.ResourcePolicyRule... resourceRules);
  public Boolean hasResourceRules();
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> addNewResourceRule();
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> addNewResourceRuleLike(ResourcePolicyRule item);
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> setNewResourceRuleLike(Integer index,ResourcePolicyRule item);
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> editResourceRule(Integer index);
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> editFirstResourceRule();
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> editLastResourceRule();
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> editMatchingResourceRule(Predicate<ResourcePolicyRuleBuilder> predicate);
  public A addToSubjects(Integer index,Subject item);
  public A setToSubjects(Integer index,Subject item);
  public A addToSubjects(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.Subject... items);
  public A addAllToSubjects(Collection<Subject> items);
  public A removeFromSubjects(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.Subject... items);
  public A removeAllFromSubjects(Collection<Subject> items);
  public A removeMatchingFromSubjects(Predicate<SubjectBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubjects instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Subject> getSubjects();
  public List<Subject> buildSubjects();
  public Subject buildSubject(Integer index);
  public Subject buildFirstSubject();
  public Subject buildLastSubject();
  public Subject buildMatchingSubject(Predicate<SubjectBuilder> predicate);
  public Boolean hasMatchingSubject(Predicate<SubjectBuilder> predicate);
  public A withSubjects(List<Subject> subjects);
  public A withSubjects(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.Subject... subjects);
  public Boolean hasSubjects();
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> addNewSubject();
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> addNewSubjectLike(Subject item);
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> setNewSubjectLike(Integer index,Subject item);
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> editSubject(Integer index);
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> editFirstSubject();
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> editLastSubject();
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> editMatchingSubject(Predicate<SubjectBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface NonResourceRulesNested<N> extends Nested<N>,NonResourcePolicyRuleFluent<PolicyRulesWithSubjectsFluent.NonResourceRulesNested<N>>{
    public N and();
    public N endNonResourceRule();
    
  }
  public interface ResourceRulesNested<N> extends Nested<N>,ResourcePolicyRuleFluent<PolicyRulesWithSubjectsFluent.ResourceRulesNested<N>>{
    public N and();
    public N endResourceRule();
    
  }
  public interface SubjectsNested<N> extends Nested<N>,SubjectFluent<PolicyRulesWithSubjectsFluent.SubjectsNested<N>>{
    public N and();
    public N endSubject();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/PolicyRulesWithSubjectsFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface PolicyRulesWithSubjectsFluent<A extends PolicyRulesWithSubjectsFluent<A>> extends Fluent<A>{
  public A addToNonResourceRules(int index,NonResourcePolicyRule item);
  public A setToNonResourceRules(int index,NonResourcePolicyRule item);
  public A addToNonResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.NonResourcePolicyRule... items);
  public A addAllToNonResourceRules(Collection<NonResourcePolicyRule> items);
  public A removeFromNonResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.NonResourcePolicyRule... items);
  public A removeAllFromNonResourceRules(Collection<NonResourcePolicyRule> items);
  public A removeMatchingFromNonResourceRules(Predicate<NonResourcePolicyRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildNonResourceRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NonResourcePolicyRule> getNonResourceRules();
  public List<NonResourcePolicyRule> buildNonResourceRules();
  public NonResourcePolicyRule buildNonResourceRule(int index);
  public NonResourcePolicyRule buildFirstNonResourceRule();
  public NonResourcePolicyRule buildLastNonResourceRule();
  public NonResourcePolicyRule buildMatchingNonResourceRule(Predicate<NonResourcePolicyRuleBuilder> predicate);
  public Boolean hasMatchingNonResourceRule(Predicate<NonResourcePolicyRuleBuilder> predicate);
  public A withNonResourceRules(List<NonResourcePolicyRule> nonResourceRules);
  public A withNonResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.NonResourcePolicyRule... nonResourceRules);
  public Boolean hasNonResourceRules();
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> addNewNonResourceRule();
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> addNewNonResourceRuleLike(NonResourcePolicyRule item);
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> setNewNonResourceRuleLike(int index,NonResourcePolicyRule item);
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> editNonResourceRule(int index);
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> editFirstNonResourceRule();
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> editLastNonResourceRule();
  public PolicyRulesWithSubjectsFluent.NonResourceRulesNested<A> editMatchingNonResourceRule(Predicate<NonResourcePolicyRuleBuilder> predicate);
  public A addToResourceRules(int index,ResourcePolicyRule item);
  public A setToResourceRules(int index,ResourcePolicyRule item);
  public A addToResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.ResourcePolicyRule... items);
  public A addAllToResourceRules(Collection<ResourcePolicyRule> items);
  public A removeFromResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.ResourcePolicyRule... items);
  public A removeAllFromResourceRules(Collection<ResourcePolicyRule> items);
  public A removeMatchingFromResourceRules(Predicate<ResourcePolicyRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResourceRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourcePolicyRule> getResourceRules();
  public List<ResourcePolicyRule> buildResourceRules();
  public ResourcePolicyRule buildResourceRule(int index);
  public ResourcePolicyRule buildFirstResourceRule();
  public ResourcePolicyRule buildLastResourceRule();
  public ResourcePolicyRule buildMatchingResourceRule(Predicate<ResourcePolicyRuleBuilder> predicate);
  public Boolean hasMatchingResourceRule(Predicate<ResourcePolicyRuleBuilder> predicate);
  public A withResourceRules(List<ResourcePolicyRule> resourceRules);
  public A withResourceRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.ResourcePolicyRule... resourceRules);
  public Boolean hasResourceRules();
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> addNewResourceRule();
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> addNewResourceRuleLike(ResourcePolicyRule item);
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> setNewResourceRuleLike(int index,ResourcePolicyRule item);
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> editResourceRule(int index);
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> editFirstResourceRule();
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> editLastResourceRule();
  public PolicyRulesWithSubjectsFluent.ResourceRulesNested<A> editMatchingResourceRule(Predicate<ResourcePolicyRuleBuilder> predicate);
  public A addToSubjects(int index,Subject item);
  public A setToSubjects(int index,Subject item);
  public A addToSubjects(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.Subject... items);
  public A addAllToSubjects(Collection<Subject> items);
  public A removeFromSubjects(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.Subject... items);
  public A removeAllFromSubjects(Collection<Subject> items);
  public A removeMatchingFromSubjects(Predicate<SubjectBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubjects instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Subject> getSubjects();
  public List<Subject> buildSubjects();
  public Subject buildSubject(int index);
  public Subject buildFirstSubject();
  public Subject buildLastSubject();
  public Subject buildMatchingSubject(Predicate<SubjectBuilder> predicate);
  public Boolean hasMatchingSubject(Predicate<SubjectBuilder> predicate);
  public A withSubjects(List<Subject> subjects);
  public A withSubjects(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.Subject... subjects);
  public Boolean hasSubjects();
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> addNewSubject();
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> addNewSubjectLike(Subject item);
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> setNewSubjectLike(int index,Subject item);
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> editSubject(int index);
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> editFirstSubject();
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> editLastSubject();
  public PolicyRulesWithSubjectsFluent.SubjectsNested<A> editMatchingSubject(Predicate<SubjectBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface NonResourceRulesNested<N> extends Nested<N>,NonResourcePolicyRuleFluent<PolicyRulesWithSubjectsFluent.NonResourceRulesNested<N>>{
    public N and();
    public N endNonResourceRule();
    
  }
  public interface ResourceRulesNested<N> extends Nested<N>,ResourcePolicyRuleFluent<PolicyRulesWithSubjectsFluent.ResourceRulesNested<N>>{
    public N and();
    public N endResourceRule();
    
  }
  public interface SubjectsNested<N> extends Nested<N>,SubjectFluent<PolicyRulesWithSubjectsFluent.SubjectsNested<N>>{
    public N and();
    public N endSubject();
    
  }
  
}
